# tessdb internal stats (overview)

Statistics database for processed logfile events and statistics emitted by the tessdb-server program


# COMMANDS

The `tess-event` command line tool is self-explanatory. You can find the all by typing `tess --help`
```
pi@rb-tess:~ $ python3 -m tess_event --help
```
